@@ -40,7 +40,7 @@ class CryptoQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 
 class CryptoManager(CommonManagetWithLookUpFieldsManager):
-    def createFromRequest(self, request, printRequest=False, function=None):
+    def createFromRequest(self, request, function=None):
         request = DSRequest(request=request)
         data = request.get_data()
         _data = data.copy()
@@ -50,14 +50,14 @@ class CryptoManager(CommonManagetWithLookUpFieldsManager):
         delAttr(_data, 'form')
         if data.get('id') or not data.get('real_name'):
             delAttr(_data, 'id')
-            res = super().update_or_create(id=data.get('id'), defaults=_data)
+            res = super().filter(id=data.get('id')).update(**_data)
             res = model_to_dict(res[0])
             delAttr(res, 'attfile')
             delAttr(res, 'form')
             data.update(res)
         return data
 
-    def updateFromRequest(self, request, printRequest=False):
+    def updateFromRequest(self, request):
         request = DSRequest(request=request)
         data = request.get_data()
         delAttr(data, 'form')
