@@ -98,7 +98,7 @@ class EventsManager:
                 parent = None
                 event = None
                 for _code in codes:
-                    if code_path == None:
+                    if code_path is None:
                         code_path = f'{_code}'
                     else:
                         code_path = f'{code_path}.{_code}'
