@@ -31,7 +31,7 @@ class Widgets_treesManager(AuditManager):
 
         id_widget = data.get('id_widget')
 
-        if id == None and mode == None and mode == None:
+        if id is None and mode is None and mode is None:
             res, create = super().update_or_create(**data)
             return res
 
