@@ -1,3 +1,4 @@
+from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
@@ -8,23 +9,13 @@ from tracker.models.messages_theme_view import Messages_theme_view, Messages_the
 
 @JsonResponseWithException(printing=False, printing_res=False)
 def Messages_theme_Fetch(request):
+    _request = DSRequest(request)
     return JsonResponse(
         DSResponse(
             request=request,
             data=Messages_theme_view.objects.
-                filter().
-                values('code',
-                       'creator_id',
-                       'deleted_at',
-                       'deliting',
-                       'description',
-                       'editing',
-                       'id',
-                       'isFolder',
-                       'lastmodified',
-                       'name',
-                       'parent_id', ).
-                distinct('id').
+                # filter().
+                filter(users__overlap=[_request.user_id]).
                 get_range_rows1(
                 request=request,
                 function=Messages_theme_view_Manager.getRecord
